@@ -158,10 +158,10 @@ def check_valid_register_form(um, client, db):
         # Create user record manually
 
         # hash password
-        kwargs['password'] = um.password_crypt_context.encrypt(password)
+        kwargs['password'] = um.hash_password(password)
 
         # Create User
-        user1 = User(active=True, email_confirmed_at=datetime.datetime.utcnow(), **kwargs)
+        user1 = User(active=True, confirmed_at=datetime.datetime.utcnow(), **kwargs)
         db.session.add(user1)
         db.session.commit()
         assert user1
@@ -175,14 +175,14 @@ def check_valid_confirm_email_page(um, client):
     print("test_valid_confirm_email_page")
 
     # Generate confirmation token for user 1
-    confirmation_token = um.token_manager.generate_token(user1.id)
+    confirmation_token = um.generate_token(user1.id)
 
     # Retrieve page and verify that response has no errors
     client.get_valid_page(url_for('user.confirm_email', token=confirmation_token))
 
     # Verify operations
     assert user1.active
-    assert user1.email_confirmed_at != None
+    assert user1.confirmed_at != None
 
 def check_valid_login_form(um, client):
     print("test_valid_login_form")
@@ -228,7 +228,7 @@ def check_valid_change_password_form(um, client):
     client.post_valid_form(url_for('user.change_password'), **kwargs)
 
     # Verify operations
-    assert um.password_crypt_context.verify(new_password, user1.password)
+    assert um.verify_password(new_password, user1.password)
 
     # Change password back to old password for subsequent tests
     user1.password = old_hashed_password
@@ -279,7 +279,7 @@ def check_valid_reset_password_page(um, client):
     print("test_valid_reset_password_page")
 
     # Simulate a valid forgot password form
-    user1.reset_password_token = um.token_manager.generate_token(user1.id)
+    user1.reset_password_token = um.generate_token(user1.id)
     token = user1.reset_password_token
 
     # Define defaults
@@ -298,7 +298,7 @@ def check_valid_reset_password_page(um, client):
     client.post_valid_form(url, **kwargs)
 
     # Verify operations
-    assert um.password_crypt_context.verify(new_password, user1.password)
+    assert um.verify_password(new_password, user1.password)
 
     # Change password back to old password for subsequent tests
     user1.password = old_hashed_password
