@@ -1,25 +1,19 @@
-"""
-    flask_user.views
-    ----------------
-    This module contains default Flask-User view functions.
+""" This file contains view functions for Flask-User forms.
 
     :copyright: (c) 2013 by Ling Thio
     :author: Ling Thio (ling.thio@gmail.com)
-    :license: Simplified BSD License, see LICENSE.txt for more details.
-"""
+    :license: Simplified BSD License, see LICENSE.txt for more details."""
 
+from datetime import datetime
 from flask import current_app, flash, redirect, render_template, request, url_for
 from flask.ext.login import current_user, login_user, logout_user
-
 from .decorators import login_required
 from .emails import send_registered_email, send_forgot_password_email
 from . import signals
 from .translations import gettext as _
 
 def confirm_email(token):
-    """
-    Verify email confirmation token and activate the user account.
-    """
+    """ Verify email confirmation token and activate the user account."""
     # Verify token
     user_manager = current_app.user_manager
     is_valid, has_expired, object_id = user_manager.verify_token(
@@ -34,8 +28,19 @@ def confirm_email(token):
         flash(_('Invalid confirmation token.'), 'error')
         return redirect(user_manager.login_url)
 
-    # Confirm email
-    user = user_manager.db_adapter.confirm_email(object_id)
+    # Confirm email by setting User.active=True and User.confirmed_at=utcnow()
+    if not user_manager.db_adapter.EmailClass:
+        user = user_manager.find_user_by_id(object_id)
+        if user:
+            user_manager.db_adapter.update_object(user,
+                    active=True,
+                    confirmed_at=datetime.utcnow(),
+                    )
+        else:                                               # pragma: no cover
+            flash(_('Invalid confirmation token.'), 'error')
+            return redirect(user_manager.login_url)
+    else:
+        raise NotImplementedError   # TODO:
 
     # Send email_confirmed signal
     signals.user_confirmed_email.send(current_app._get_current_object(), user=user)
@@ -48,9 +53,7 @@ def confirm_email(token):
 
 @login_required
 def change_password():
-    """
-    Prompt for old password and new password and change the user's password.
-    """
+    """ Prompt for old password and new password and change the user's password."""
     user_manager =  current_app.user_manager
 
     # Initialize form
@@ -63,7 +66,7 @@ def change_password():
         hashed_password = user_manager.hash_password(form.new_password.data)
 
         # Change password
-        user_manager.db_adapter.set_object_fields(current_user, password=hashed_password)
+        user_manager.db_adapter.update_object(current_user, password=hashed_password)
 
         # Send password_changed signal
         signals.user_changed_password.send(current_app._get_current_object(), user=current_user)
@@ -77,12 +80,9 @@ def change_password():
     # Process GET or invalid POST
     return render_template(user_manager.change_password_template, form=form)
 
-
 @login_required
 def change_username():
-    """
-    Prompt for new username and old password and change the user's username.
-    """
+    """ Prompt for new username and old password and change the user's username."""
     user_manager =  current_app.user_manager
 
     # Initialize form
@@ -94,7 +94,7 @@ def change_username():
         new_username = form.new_username.data
 
         # Change username
-        user_manager.db_adapter.set_object_fields(current_user, username=new_username)
+        user_manager.db_adapter.update_object(current_user, username=new_username)
 
         # Send username_changed signal
         signals.user_changed_username.send(current_app._get_current_object(), user=current_user)
@@ -110,9 +110,7 @@ def change_username():
 
 
 def forgot_password():
-    """
-    Prompt for email and send reset password email.
-    """
+    """Prompt for email and send reset password email."""
     user_manager =  current_app.user_manager
 
     # Initialize form
@@ -123,14 +121,14 @@ def forgot_password():
         email = form.email.data
 
         # Find user by email
-        user = user_manager.db_adapter.find_user_by_email(email)
+        user = user_manager.find_user_by_email(email)
         if user:
             # Generate password reset token
             token = user_manager.generate_token(user.id)
 
             # Store token
             if hasattr(user, 'reset_password_token'):
-                user_manager.db_adapter.set_object_fields(user, reset_password_token=token)
+                user_manager.db_adapter.update_object(user, reset_password_token=token)
 
             # Send forgot password email
             send_forgot_password_email(email, user, token)
@@ -149,9 +147,7 @@ def forgot_password():
 
 
 def login():
-    """
-    Prompt for username/email and password and sign the user in.
-    """
+    """ Prompt for username/email and password and sign the user in."""
     user_manager =  current_app.user_manager
 
     # Initialize form
@@ -162,9 +158,13 @@ def login():
     if request.method=='POST' and form.validate():
         # Retrieve User
         if user_manager.enable_username:
-            user = user_manager.db_adapter.find_user_by_username(form.username.data)
+            # Find user by username or email address
+            user = user_manager.find_user_by_username(form.username.data)
+            if not user and user_manager.enable_email:
+                user = user_manager.find_user_by_email(form.username.data)
         else:
-            user = user_manager.db_adapter.find_user_by_email(form.email.data)
+            # Find user by email address
+            user = user_manager.find_user_by_email(form.email.data)
 
         if user:
             if user.active:
@@ -185,15 +185,11 @@ def login():
                 else:
                     flash(_('Your account has been disabled.'), 'error')
 
-
     # Process GET or invalid POST
     return render_template(user_manager.login_template, form=form)
 
-
 def logout():
-    """
-    Sign the user out.
-    """
+    """ Sign the user out."""
     user_manager =  current_app.user_manager
 
     # Send user_logged_out signal
@@ -211,9 +207,7 @@ def logout():
 
 
 def register():
-    """
-    Prompt for username/email and password, send confirmation email, and create an inactive user account.
-    """
+    """ Prompt for username/email and password, send confirmation email, and create an inactive user account."""
     user_manager =  current_app.user_manager
 
     # Initialize form
@@ -258,7 +252,7 @@ def register():
             user_kwargs['active'] = True
 
         # Add User record with named arguments
-        user = user_manager.db_adapter.add_user(**user_kwargs)
+        user = user_manager.db_adapter.add_object(user_manager.db_adapter.UserClass, **user_kwargs)
 
         # For multiple emails per user, add Email object
         if user_manager.db_adapter.EmailClass:
@@ -298,42 +292,9 @@ def register():
 # TODO:
 def resend_confirm_email():
     pass
-    # """
-    # Prompt for email and re-send the confirmation email.
-    # """
-    # user_manager =  current_app.user_manager
-    #
-    # # Initialize form
-    # form = user_manager.resend_confirm_email_form(request.form)
-    #
-    # # Process valid POST
-    # if request.method=='POST' and form.validate():
-    #     email = form.email.data
-    #
-    #     # Find user by email
-    #     user = user_manage.db_adapter.find_user_by_email(email)
-    #     if user:
-    #
-    #         # Send confirmation email
-    #         send_confirm_email_email(email, user)
-    #
-    #     # Prepare one-time system message
-    #     flash(_("A confirmation email has been sent to %(email)s. Open that email and follow the instructions to complete your registration.", email=email), 'success')
-    #
-    #     # Redirect to 'next' URL or '/'
-    #     next = form.next.data
-    #     if not next:
-    #         return redirect('/')
-    #     return redirect(next)
-    #
-    # # Process GET or invalid POST
-    # return render_template(user_manager.resend_confirm_email_template, form=form)
-
 
 def reset_password(token):
-    """
-    Verify the password reset token, Prompt for new password, and set the user's password.
-    """
+    """ Verify the password reset token, Prompt for new password, and set the user's password."""
     # Verify token
     user_manager = current_app.user_manager
     is_valid, has_expired, user_id = user_manager.verify_token(
@@ -348,7 +309,7 @@ def reset_password(token):
         flash(_('Your reset password token is invalid.'), 'error')
         return redirect(user_manager.login_url)
 
-    user = user_manager.db_adapter.find_user_by_id(user_id)
+    user = user_manager.find_user_by_id(user_id)
     if user:
         # Avoid re-using old tokens
         if hasattr(user, 'reset_password_token'):
@@ -366,11 +327,11 @@ def reset_password(token):
     if request.method=='POST' and form.validate():
         # Invalidate the token by clearing the stored token
         if hasattr(user, 'reset_password_token'):
-            user_manager.db_adapter.set_object_fields(user, reset_password_token='')
+            user_manager.db_adapter.update_object(user, reset_password_token='')
 
         # Change password
         hashed_password = user_manager.hash_password(form.new_password.data)
-        user_manager.db_adapter.set_object_fields(user, password=hashed_password)
+        user_manager.db_adapter.update_object(user, password=hashed_password)
 
         # Prepare one-time system message
         flash(_("Your password has been reset successfully. Please sign in with your new password"), 'success')
@@ -382,24 +343,20 @@ def reset_password(token):
     return render_template(user_manager.reset_password_template, form=form)
 
 def unauthenticated():
-    """
-    Prepare a Flash message and redirect to USER_UNAUTHENTICATED_URL
-    """
+    """ Prepare a Flash message and redirect to USER_UNAUTHENTICATED_URL"""
     # Prepare Flash message
     url = request.script_root + request.path
-    flash(_('You must be signed in to access %(url)s.', url=url), 'error')
+    flash(_("You must be signed in to access '%(url)s'.", url=url), 'error')
 
     # Redirect to USER_UNAUTHENTICATED_URL
     user_manager = current_app.user_manager
     return redirect(user_manager.unauthenticated_url)
 
 def unauthorized():
-    """
-    Prepare a Flash message and redirect to USER_UNAUTHORIZED_URL
-    """
+    """ Prepare a Flash message and redirect to USER_UNAUTHORIZED_URL"""
     # Prepare Flash message
     url = request.script_root + request.path
-    flash(_('You do not have permission to access %(url)s.', url=url), 'error')
+    flash(_("You do not have permission to access '%(url)s'.", url=url), 'error')
 
     # Redirect to USER_UNAUTHORIZED_URL
     user_manager = current_app.user_manager
